@@ -14,7 +14,7 @@ use Monitoring::Generator::TestConfig::P1Data;
 use Monitoring::Generator::TestConfig::Modules::Shinken;
 use Monitoring::Generator::TestConfig::ShinkenInitScriptData;
 
-our $VERSION = '0.48';
+our $VERSION = '0.50';
 
 =head1 NAME
 
@@ -61,14 +61,16 @@ Arguments are in key-value pairs.
     host_types                  key/value settings for percentage of hosttypes, possible keys are up,down,flap,random,block
     router_types                key/value settings for percentage of hosttypes for router
     service_types               key/value settings for percentage of servicetypes, possible keys are ok,warning,critical,unknown,flap,random,block
-    skip_dependencys            no service dependencys will be exported
-    contactscount               amount of contacts to export, Default 1
-    contactgroupscount          amount of contactgroups to export, Default 1
-    contactspergroup            amount of contacts to export, Default 1
-    contactsperhost             amount of contacts per host, Default 0
-    contactgroupsperhost        amount of contactgroups per host, Default 1
-    contactsperservice          amount of contacts per service, Default 0
-    contactgroupsperservice     amount of contactgroups per service, Default 1
+    skip_dependencies           no service dependencies will be exported
+    contacts_count              amount of contacts to export, Default 1
+    contactgroups_count         amount of contactgroups to export, Default 1
+    contacts_per_group          amount of contacts to export, Default 1
+    contacts_per_host           amount of contacts per host, Default 0
+    contactgroups_per_host      amount of contactgroups per host, Default 1
+    contacts_per_service        amount of contacts per service, Default 0
+    contactgroups_per_service   amount of contactgroups per service, Default 1
+    skip_hostgroups             no hostgroups will be exported
+    skip_servicegroups          no servicegroups will be exported
 
 =back
 
@@ -86,13 +88,13 @@ sub new {
                     'prefix'              => '',
                     'overwrite_dir'       => 0,
                     'binary'              => undef,
-                    'contactscount'       => 1,
-                    'contactgroupscount'  => 1,
-                    'contactspergroup'    => 1,
-                    'contactsperhost'     => 0,
-                    'contactgroupsperhost'=> 1,
-                    'contactsperservice'  => 0,
-                    'contactgroupsperservice' => 1,
+                    'contacts_count'      => 1,
+                    'contactgroups_count' => 1,
+                    'contacts_per_group'  => 1,
+                    'contacts_per_host'   => 0,
+                    'contactgroups_per_host' => 1,
+                    'contacts_per_service'  => 0,
+                    'contactgroups_per_service' => 1,
                     'routercount'         => 5,
                     'hostcount'           => 10,
                     'hostcheckcmd'        => undef,
@@ -103,7 +105,9 @@ sub new {
                     'service_settings'    => {},
                     'servicefailrate'     => 5,
                     'hostfailrate'        => 2,
-                    'skip_dependencys'    => 0,
+                    'skip_dependencies'   => 0,
+                    'skip_hostgroups'     => 0,
+                    'skip_servicegroups'  => 0,
                     'fixed_length'        => 0,
                     'router_types'        => {
                                     'down'         => 10,
@@ -293,9 +297,9 @@ sub create {
     my $objects = {};
     my($contactnames, $contactgroupnames) = $self->_set_contacts_cfg($objects);
     $objects = $self->_set_hosts_cfg($objects, $contactnames, $contactgroupnames);
-    $objects = $self->_set_hostgroups_cfg($objects);
+    $objects = $self->_set_hostgroups_cfg($objects) unless $self->{'skip_hostgroups'};
     $objects = $self->_set_services_cfg($objects, $contactnames, $contactgroupnames);
-    $objects = $self->_set_servicegroups_cfg($objects);
+    $objects = $self->_set_servicegroups_cfg($objects) unless $self->{'skip_servicegroups'};
     $objects = $self->_set_commands_cfg($objects);
     $objects = $self->_set_timeperiods_cfg($objects);
     my $obj_prefix = '/etc/conf.d';
@@ -346,7 +350,7 @@ sub create {
 
     # export service dependencies
     my $servicedependency = "";
-    unless ($self->{'skip_dependencys'} ) {
+    unless ($self->{'skip_dependencies'} ) {
         $objects = $self->_set_servicedependency_cfg($objects);
         $servicedependency = $self->_create_object_conf('servicedependency', $objects->{'servicedependency'});
     }
@@ -436,6 +440,7 @@ sub _set_hosts_cfg {
                 'icon_image'    => '../../docs/images/switch.png',
             };
             $host->{'active_checks_enabled'} = '0' if $type eq 'pending';
+            delete $host->{'hostgroups'} if $self->{'skip_hostgroups'};
 
             # first router gets additional infos
             if($x == 0) {
@@ -455,14 +460,14 @@ sub _set_hosts_cfg {
 
             # add contacts
             my @contacts = ();
-            for(my $z = 0; $z < $self->{'contactsperhost'}; $z++) {
+            for(my $z = 0; $z < $self->{'contacts_per_host'}; $z++) {
                 push @contacts, $contactnames->[ rand @{$contactnames} ];
             }
             $host->{'contacts'} = join(',', @contacts) if scalar @contacts > 0;
 
             # add contactgroups
             my @contactgroups = ();
-            for(my $z = 0; $z < $self->{'contactgroupsperhost'}; $z++) {
+            for(my $z = 0; $z < $self->{'contactgroups_per_host'}; $z++) {
                 push @contactgroups, $contactgroupnames->[ rand @{$contactgroupnames} ];
             }
             $host->{'contact_groups'} = join(',', @contactgroups) if scalar @contactgroups > 0;
@@ -499,17 +504,18 @@ sub _set_hosts_cfg {
             $host->{'check_command'} = 'test-check-host-alive-parent!'.$type.'!$HOSTSTATE:'.$router[$cur_router].'$';
         }
         $host->{'active_checks_enabled'} = '0' if $type eq 'pending';
+        delete $host->{'hostgroups'} if $self->{'skip_hostgroups'};
 
         # add contacts
         my @contacts = ();
-        for(my $z = 0; $z < $self->{'contactsperhost'}; $z++) {
+        for(my $z = 0; $z < $self->{'contacts_per_host'}; $z++) {
             push @contacts, $contactnames->[ rand @{$contactnames} ];
         }
         $host->{'contacts'} = join(',', @contacts) if scalar @contacts > 0;
 
         # add contactgroups
         my @contactgroups = ();
-        for(my $z = 0; $z < $self->{'contactgroupsperhost'}; $z++) {
+        for(my $z = 0; $z < $self->{'contactgroups_per_host'}; $z++) {
             push @contactgroups, $contactgroupnames->[ rand @{$contactgroupnames} ];
         }
         $host->{'contact_groups'} = join(',', @contactgroups) if scalar @contactgroups > 0;
@@ -602,6 +608,7 @@ sub _set_services_cfg {
             };
 
             $service->{'active_checks_enabled'} = '0' if $type eq 'pending';
+            delete $service->{'servicegroups'} if $self->{'skip_servicegroups'};
 
             # first router gets additional infos
             if($y == 0) {
@@ -622,14 +629,14 @@ sub _set_services_cfg {
 
             # add contacts
             my @contacts = ();
-            for(my $z = 0; $z < $self->{'contactsperservice'}; $z++) {
+            for(my $z = 0; $z < $self->{'contacts_per_service'}; $z++) {
                 push @contacts, $contactnames->[ rand @{$contactnames} ];
             }
             $service->{'contacts'} = join(',', @contacts) if scalar @contacts > 0;
 
             # add contactgroups
             my @contactgroups = ();
-            for(my $z = 0; $z < $self->{'contactgroupsperservice'}; $z++) {
+            for(my $z = 0; $z < $self->{'contactgroups_per_service'}; $z++) {
                 push @contactgroups, $contactgroupnames->[ rand @{$contactgroupnames} ];
             }
             $service->{'contact_groups'} = join(',', @contactgroups) if scalar @contactgroups > 0;
@@ -699,8 +706,8 @@ sub _set_contacts_cfg {
 
     $objects->{'contact'} = [] unless defined $objects->{'contact'};
     my @contacts = ();
-    my $nr_length = $self->{'fixed_length'} || length($self->{'contactscount'});
-    for(my $x = 0; $x < $self->{'contactscount'}; $x++) {
+    my $nr_length = $self->{'fixed_length'} || length($self->{'contacts_count'});
+    for(my $x = 0; $x < $self->{'contacts_count'}; $x++) {
         my $nr   = sprintf("%0".$nr_length."d", $x);
         my $name = $self->{'prefix'}."contact_".$nr;
         push @contacts, $name;
@@ -719,11 +726,11 @@ sub _set_contacts_cfg {
 
     my @contactgroups = ();
     $objects->{'contactgroup'} = [] unless defined $objects->{'contactgroup'};
-    $nr_length = $self->{'fixed_length'} || length($self->{'contactgroupscount'});
-    for(my $x = 0; $x < $self->{'contactgroupscount'}; $x++) {
+    $nr_length = $self->{'fixed_length'} || length($self->{'contactgroups_count'});
+    for(my $x = 0; $x < $self->{'contactgroups_count'}; $x++) {
         my $nr = sprintf("%0".$nr_length."d", $x);
         my @members = ();
-        for(my $y = 0; $y < $self->{'contactspergroup'}; $y++) {
+        for(my $y = 0; $y < $self->{'contacts_per_group'}; $y++) {
             push @members, $contacts[ rand @contacts ];
         }
         my $name = $self->{'prefix'}."contactgroup_".$nr;
